@@ -131,7 +131,7 @@ class CreateQuery(BaseQuery):
     def _raw_exec(self, transaction_or_batch=None, merge=None):
         """save model into firestore and return the document"""
         ref = self._doc_ref()
-        if transaction_or_batch:
+        if transaction_or_batch is not None:
             if merge:
                 transaction_or_batch.set(
                     ref, self._parse_field(), merge=merge)
@@ -153,6 +153,6 @@ class CreateQuery(BaseQuery):
 
     def exec(self, transaction_or_batch=None, merge=None):
         """return modified or new instance of model"""
-        if transaction_or_batch:
+        if transaction_or_batch is not None:
             return self._raw_exec(transaction_or_batch, merge)
         return query_wrapper.ModelWrapper.from_query_result(self.model, self._raw_exec(merge=merge))
